@@ -57,9 +57,8 @@ class TonTvm(TonModule):
 
         If you need this emulation to be as precise as possible
         (for instance - emulate transaction with particular lt in particular
-        block or use particular blockchain config, in case you want to
-        download it from a particular key block - then specify
-        `ParamsOfRunExecutor` parameter.
+        block or use particular blockchain config, downloaded from a
+        particular key block - then specify `execution_options` parameter.
 
         If you need to see the aborted transaction as a result, not as an
         error, set `skip_transaction_check` to true.
